==> nextcloud-32.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/workflowengine/l10n/et_EE.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Antud operaator/tehtemärk on vigane",
    "The given regular expression is invalid" : "Antud regulaaravaldis on vigane",
    "The given file size is invalid" : "Antud faili suurus on vigane",
    "The given tag id is invalid" : "Antud sildi tunnus on vigane",
    "The given IP range is invalid" : "Antud IP-aadresside vahemik on vigane",
    "The given IP range is not valid for IPv4" : "Antud IP vahemik ei kehti IPv4 kohta",
    "The given IP range is not valid for IPv6" : "Antud IP vahemik ei kehti IPv6 kohta",
    "The given time span is invalid" : "Antud ajavahemik on vigane",
    "The given start time is invalid" : "Antud algusaeg on vigane",
    "The given end time is invalid" : "Antud lõppaeg on vigane",
    "The given group does not exist" : "Antud gruppi ei leitud",
    "File" : "Fail",
    "File created" : "Fail on loodud",
    "File updated" : "Fail on uuendatud",
    "File renamed" : "Faili nimi on muudetud",
    "File deleted" : "Fail on kustutatud",
    "File accessed" : "Faili on kasutatud",
    "File copied" : "Fail on kopeeritud",
    "Tag assigned" : "Silt on lisatud",
    "Someone" : "Keegi",
    "%s created %s" : "%s lõi %s",
    "%s modified %s" : "%s muutis %s",
    "%s deleted %s" : "%s kustutas %s",
    "%s accessed %s" : "%s kasutas töövoogu %s",
    "%s renamed %s" : "%s muutis %s nime",
    "%s copied %s" : "%s kopeeris %s",
    "%s assigned %s to %s" : "%s määras %s kasutajale %s",
    "Operation #%s does not exist" : "Tegevus # %s ei leitud",
    "Entity %s does not exist" : "%s objekti pole olemas",
    "Entity %s is invalid" : "%s objekt on vigane",
    "No events are chosen." : "Ühtegi sündmust pole valitud.",
    "Entity %s has no event %s" : "%s objektil pole %s sündmust",
    "Operation %s does not exist" : "%s tegevust pole olemas",
    "Operation %s is invalid" : " %s tegevus on vigane",
    "At least one check needs to be provided" : "Pead lisama vähemalt ühe kontrolli",
    "The provided operation data is too long" : "Lisatud tegevuse andmed on liiga mahukad",
    "Invalid check provided" : "Oled lisanud vigase kontrolli",
    "Check %s does not exist" : "%s kontrolli pole olemas",
    "Check %s is invalid" : "%s kontroll on vigane",
    "Check %s is not allowed with this entity" : "Selle objekti puhul ei saa kasutada seda kontrolli: %s",
    "The provided check value is too long" : "Lisatud kontrolli väärtus on liiga pikk",
    "Check #%s does not exist" : "Kontrolli #%s pole olemas",
    "Check %s is invalid or does not exist" : "%s kontroll on vigane või pole teda olemas",
    "Flow" : "Töövoog",
    "Nextcloud workflow engine" : "Nextcloudi töövoogude mootor",
    "Select a filter" : "Vali filter",
    "Select a comparator" : "Vali võrdleja",
    "Remove filter" : "Eemalda filter",
    "Audio" : "Helifailid",
    "Folder" : "Kaust",
    "Images" : "Pildid",
    "Office documents" : "Kontroritarkvara dokumendid",
    "PDF documents" : "PDF-dokumendid",
    "Video" : "Video",
    "Custom MIME type" : "Sinu määratud MIME-tüüp",
    "Custom mimetype" : "Sinu määratud MIME-tüüp",
    "Select a file type" : "Vali failitüüp",
    "e.g. httpd/unix-directory" : "nt. httpd/unix-directory",
    "Please enter a valid time span" : "Palun sisesta korrektne ajavahemik",
    "Files WebDAV" : "WebDAV-i failid",
    "Custom URL" : "Sinu määratud võrguaadress",
    "Select a request URL" : "Vali päringu võrguaadress",
    "Android client" : "Android klient",
    "iOS client" : "iOS-i klient",
    "Desktop client" : "Töölaua klient",
    "Thunderbird & Outlook addons" : "Thunderbirdi ja Outlooki lisad",
    "Custom user agent" : "Sinu määratud rakenduse tunnus",
    "Select a user agent" : "Vali rakenduse tunnus",
    "Select groups" : "Vali grupid",
    "Groups" : "Grupid",
    "Type to search for group …" : "Grupi otsimiseks kirjuta midagi…",
    "Select a trigger" : "Vali päästik",
    "At least one event must be selected" : "Palun valitud vähemalt üks sündmus",
    "Add new flow" : "Lisa uus töövoog",
    "The configuration is invalid" : "Seadistus on vigane",
    "Active" : "Aktiivne",
    "Save" : "Salvesta",
    "When" : "Millal",
    "and" : "ja",
    "Add a new filter" : "Lisa uus filter",
    "Cancel" : "Loobu",
    "Delete" : "Kustuta",
    "Available flows" : "Saadaval töövood",
    "For details on how to write your own flow, check out the development documentation." : "Lisateavet oma töövoogude kirjutamiseks leiad dokumentatsioonist arendajatele.",
    "No flows installed" : "Ühtegi töövoogu pole paigaldatud",
    "Ask your administrator to install new flows." : "Palu oma serveri haldajat, et ta paigaldaks uusi töövooge.",
    "More flows" : "Veel töövooge",
    "Browse the App Store" : "Sirvi rakendustepoodi",
    "Show less" : "Näita vähem",
    "Show more" : "Näita rohkem",
    "Configured flows" : "Seadistatud töövood",
    "Your flows" : "Sinu töövood",
    "No flows configured" : "Ühtegi töövoogu pole seadistatud",
    "matches" : "kattub",
    "does not match" : "ei kattu",
    "is" : "on",
    "is not" : "ei ole",
    "File name" : "Failinimi",
    "File MIME type" : "Faili MIME-tüüp",
    "File size (upload)" : "Faili suurus (üleslaadimine)",
    "less" : "väiksem",
    "less or equals" : "väiksem või võrdne",
    "greater or equals" : "suurem või võrdne",
    "greater" : "suurem",
    "Request remote address" : "Päringu kaugaadress",
    "matches IPv4" : "kattub IPv4 aadressiga",
    "does not match IPv4" : "Ei kattu IPv4 aadressiga",
    "matches IPv6" : "kattub IPv6 aadressiga",
    "does not match IPv6" : "Ei kattu IPv6 aadressiga",
    "File system tag" : "Failisüsteemi silt",
    "is tagged with" : "on sildiga",
    "is not tagged with" : "ei ole märgitud sildiga",
    "Request URL" : "Päringu võrguaadress",
    "Request time" : "Päringu aeg",
    "between" : "vahemikus",
    "not between" : "ei ole vahemikus",
    "Request user agent" : "Päri rakenduse tunnust",
    "Group membership" : "Grupi liikmelisus",
    "is member of" : "on liige",
    "is not member of" : "ei ole liige"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/workflowengine/l10n/et_EE.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Antud operaator/tehtemärk on vigane",
    "The given regular expression is invalid" : "Antud regulaaravaldis on vigane",
    "The given file size is invalid" : "Antud faili suurus on vigane",
    "The given tag id is invalid" : "Antud sildi tunnus on vigane",
    "The given IP range is invalid" : "Antud IP-aadresside vahemik on vigane",
    "The given IP range is not valid for IPv4" : "Antud IP vahemik ei kehti IPv4 kohta",
    "The given IP range is not valid for IPv6" : "Antud IP vahemik ei kehti IPv6 kohta",
    "The given time span is invalid" : "Antud ajavahemik on vigane",
    "The given start time is invalid" : "Antud algusaeg on vigane",
    "The given end time is invalid" : "Antud lõppaeg on vigane",
    "The given group does not exist" : "Antud gruppi ei leitud",
    "File" : "Fail",
    "File created" : "Fail on loodud",
    "File updated" : "Fail on uuendatud",
    "File renamed" : "Faili nimi on muudetud",
    "File deleted" : "Fail on kustutatud",
    "File accessed" : "Faili on kasutatud",
    "File copied" : "Fail on kopeeritud",
    "Tag assigned" : "Silt on lisatud",
    "Someone" : "Keegi",
    "%s created %s" : "%s lõi %s",
    "%s modified %s" : "%s muutis %s",
    "%s deleted %s" : "%s kustutas %s",
    "%s accessed %s" : "%s kasutas töövoogu %s",
    "%s renamed %s" : "%s muutis %s nime",
    "%s copied %s" : "%s kopeeris %s",
    "Operation #%s does not exist" : "Tegevus # %s ei leitud",
    "Entity %s is invalid" : "%s objekt on vigane",
    "Entity %s does not exist" : "%s objekti pole olemas",
    "No events are chosen." : "Ühtegi sündmust pole valitud.",
    "Entity %s has no event %s" : "%s objektil pole %s sündmust",
    "The provided operation data is too long" : "Lisatud tegevuse andmed on liiga mahukad",
    "Operation %s is invalid" : " %s tegevus on vigane",
    "Operation %s does not exist" : "%s tegevust pole olemas",
    "At least one check needs to be provided" : "Pead lisama vähemalt ühe kontrolli",
    "Invalid check provided" : "Oled lisanud vigase kontrolli",
    "The provided check value is too long" : "Lisatud kontrolli väärtus on liiga pikk",
    "Check %s is invalid" : "%s kontroll on vigane",
    "Check %s does not exist" : "%s kontrolli pole olemas",
    "Check %s is not allowed with this entity" : "Selle objekti puhul ei saa kasutada seda kontrolli: %s",
    "Check #%s does not exist" : "Kontrolli #%s pole olemas",
    "Check %s is invalid or does not exist" : "%s kontroll on vigane või pole teda olemas",
    "Flow" : "Töövoog",
    "Nextcloud workflow engine" : "Nextcloudi töövoogude mootor",
    "Select a filter" : "Vali filter",
    "Select a comparator" : "Vali võrdleja",
    "Remove filter" : "Eemalda filter",
    "Audio" : "Helifailid",
    "Folder" : "Kaust",
    "Images" : "Pildid",
    "Office documents" : "Kontroritarkvara dokumendid",
    "PDF documents" : "PDF-dokumendid",
    "Video" : "Video",
    "Custom MIME type" : "Sinu määratud MIME-tüüp",
    "Select a file type" : "Vali failitüüp",
    "e.g. httpd/unix-directory" : "nt. httpd/unix-directory",
    "Please enter a valid time span" : "Palun sisesta korrektne ajavahemik",
    "Files WebDAV" : "WebDAV-i failid",
    "Custom URL" : "Sinu määratud võrguaadress",
    "Select a request URL" : "Vali päringu võrguaadress",
    "Android client" : "Android klient",
    "iOS client" : "iOS-i klient",
    "Desktop client" : "Töölaua klient",
    "Thunderbird & Outlook addons" : "Thunderbirdi ja Outlooki lisad",
    "Custom user agent" : "Sinu määratud rakenduse tunnus",
    "Select a user agent" : "Vali rakenduse tunnus",
    "Select groups" : "Vali grupid",
    "Groups" : "Grupid",
    "Select a trigger" : "Vali päästik",
    "At least one event must be selected" : "Palun valitud vähemalt üks sündmus",
    "Add new flow" : "Lisa uus töövoog",
    "The configuration is invalid" : "Seadistus on vigane",
    "Active" : "Aktiivne",
    "Save" : "Salvesta",
    "When" : "Millal",
    "and" : "ja",
    "Add a new filter" : "Lisa uus filter",
    "Cancel" : "Loobu",
    "Delete" : "Kustuta",
    "Available flows" : "Saadaval töövood",
    "For details on how to write your own flow, check out the development documentation." : "Lisateavet oma töövoogude kirjutamiseks leiad dokumentatsioonist arendajatele.",
    "No flows installed" : "Ühtegi töövoogu pole paigaldatud",
    "Ask your administrator to install new flows." : "Palu oma serveri haldajat, et ta paigaldaks uusi töövooge.",
    "More flows" : "Veel töövooge",
    "Browse the App Store" : "Sirvi rakendustepoodi",
    "Show less" : "Näita vähem",
    "Show more" : "Näita rohkem",
    "Configured flows" : "Seadistatud töövood",
    "Your flows" : "Sinu töövood",
    "No flows configured" : "Ühtegi töövoogu pole seadistatud",
    "matches" : "kattub",
    "does not match" : "ei kattu",
    "is" : "on",
    "is not" : "ei ole",
    "File name" : "Failinimi",
    "File MIME type" : "Faili MIME-tüüp",
    "File size (upload)" : "Faili suurus (üleslaadimine)",
    "less" : "väiksem",
    "less or equals" : "väiksem või võrdne",
    "greater or equals" : "suurem või võrdne",
    "greater" : "suurem",
    "Request remote address" : "Päringu kaugaadress",
    "matches IPv4" : "kattub IPv4 aadressiga",
    "does not match IPv4" : "Ei kattu IPv4 aadressiga",
    "matches IPv6" : "kattub IPv6 aadressiga",
    "does not match IPv6" : "Ei kattu IPv6 aadressiga",
    "File system tag" : "Failisüsteemi silt",
    "is tagged with" : "on sildiga",
    "is not tagged with" : "ei ole märgitud sildiga",
    "Request URL" : "Päringu võrguaadress",
    "Request time" : "Päringu aeg",
    "between" : "vahemikus",
    "not between" : "ei ole vahemikus",
    "Request user agent" : "Päri rakenduse tunnust",
    "Group membership" : "Grupi liikmelisus",
    "is member of" : "on liige",
    "is not member of" : "ei ole liige",
    "Type to search for group …" : "Grupi otsimiseks kirjuta midagi…"
},
"nplurals=2; plural=(n != 1);");
